pyhsm.aead_cmd

Package pyhsm :: Module aead_cmd |
[frames] | no frames]

# Module aead_cmd

implementations of AEAD commands for the YubiHSM

Classes
| YHSM_AEAD_Cmd Class for common non-trivial parse_result for commands returning a YSM_AEAD_GENERATE_RESP.
| YHSM_Cmd_AEAD_Generate Generate AEAD block from data for a specific key.
| YHSM_Cmd_AEAD_Random_Generate Generate a random AEAD block using the YubiHSM internal TRNG.
| YHSM_Cmd_AEAD_Buffer_Generate Generate AEAD block of data buffer for a specific key.
| YHSM_Cmd_AEAD_Decrypt_Cmp Validate an AEAD using the YubiHSM, matching it against some known plain text.
| YHSM_GeneratedAEAD Small class to represent a YHSM_AEAD_GENERATE_RESP.
| YHSM_YubiKeySecret Small class to represent a YUBIKEY_SECRETS struct.

Variables
| YHSM_AEAD_File_Marker = ``'``YubiHSM AEAD\n``'``